Settings
========

Mailman Web supports following settings.

.. automodule:: mailman_web.settings.base
    :members:
    :ignore-module-all:
    :undoc-members:

.. automodule:: mailman_web.settings.mailman
    :members:
    :ignore-module-all:
    :undoc-members:
